#
# Label Support Class
# (C) Copyright 2001 bluedynamics.com
# All Rights Reserved
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#  1. Redistributions of source code must retain the above copyright
#     notice, this list of conditions and the following disclaimer.
#  2. Redistributions in binary form must reproduce the above copyright
#     notice, this list of conditions and the following disclaimer in the
#     documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#
# Author: Stephan Richter <srichter@iuveno-net.de>

from OFS.Image import File
from Globals import HTMLFile, MessageDialog

import string

seperator = '|||'

class ImportExportSupport:
    '''ImportExportSupport class - Support class to allow import and export of ZBabelTower data'''

    manage_options = ({'label': 'Export/Import',   'action': 'manage_importExport'},)

    manage_importExport = HTMLFile('manage_importExport', globals())


    def exportData(self):
        '''exportData(self) --> exports the data to a single text string; return string'''
        text = ''
        for row in self.qry_getAllPhrases():
            for field in ['lang', 'md5hash', 'rendertext', 'renderpath']:
                text = text + row[field] + seperator

            text = text + '\n'

        return text


    def importData(self, text):
        '''importData(self, text) --> imports the data from a single text data string; return None'''
        rows = filter(None, string.split(text, seperator+'\n'))
        for row in rows:
            fields = string.split(row, seperator)
            self.sql_newPhrase(lang=fields[0], md5Hash=fields[1], renderText=fields[2],
                               renderPath=fields[3])



    def exportToFile(self, fileId='ZBabelDictionary_txt'):
        '''exportToFile(self, fileId='ZBabelDictionary_txt') --> export the data to a ZODB File; return File'''
        text = self.exportData()
	return File(fileId, 'ZBabel Export File', text)



    def importFromFile(self, file):
        '''importFromFile(self, file) --> retrieve data from a ZODB File; return None'''
        self.importData(file.data)        


    def exportToFolder(self, folder=None, fileId='ZBabelDictionary_txt', REQUEST=None):
        '''exportToFolder(self, folder=None, fileId='ZBabelDictionary_txt', REQUEST=None) --> save the data
           in a file inside the specified directory; return HTML'''
        if not folder:
            folder = self.aq_parent

        folder._delOb('ZBabelDictionary.txt')
        folder._setObject(fileId, self.exportToFile(fileId))
        if REQUEST:
            return MessageDialog(title='Data exported to %s' %fileId,
                                 message='All of the translations in this ZBabelTower contains has been exported!',
                                 action ='./manage_main',)


    def importFromFolder(self, folder=None, fileId='ZBabelDictionary_txt', REQUEST=None):
        '''importFromFolder(self, folder=None, fileId='ZBabelDictionary_txt', REQUEST=None) --> import the data
           from a specified file in a specific directory; return HTML'''
        if not folder:
            folder = self.aq_parent

        self.importFromFile(folder[fileId])
        if REQUEST:
            return MessageDialog(title='Data imported from %s' %fileId,
                                 message='All of the found translations have been imported!',
                                 action ='./manage_main',)
